<?php

/**
 * @file
 * DrupalGap's implementation of Hooks provided by Services
 * for the definition of new service resources.
 */

/**
 * Defines function signatures for resources available to services.
 */
function drupalgap_services_resources() {
  $drupalgap_resource = array(
    'drupalgap_content' => array(
      'actions' => array(
        'content_types_list' => array(
          'help' => t('Gets a list of Drupal content types.'),
          'file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'callback' => '_drupalgap_resource_content_types_list',
          'args' => array(),
          'access callback' => '_drupalgap_resource_access',
          'access callback file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'access arguments' => array('access content'),
          'access arguments append' => TRUE,
        ),
        'content_types_user_permissions' => array(
          'help' => t('Returns a list of permissions the current user has for
           all content types.'),
          'file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'callback' => '_drupalgap_resource_content_types_user_permissions',
          'args' => array(),
          'access callback' => '_drupalgap_resource_access',
          'access callback file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'access arguments' => array('access content'),
          'access arguments append' => TRUE,
        ),
      ),
    ),
    'drupalgap_system' => array(
      'actions' => array(
        'site_settings' => array(
          'help' => t('Gets a list of various drupal settings and variables.'),
          'file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'callback' => '_drupalgap_resource_system_site_settings',
          'args' => array(),
          'access callback' => '_drupalgap_resource_access',
          'access callback file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'access arguments' => array('access content'),
          'access arguments append' => TRUE,
        ),
      ),
    ),
    'drupalgap_user' => array(
      'actions' => array(
        'access' => array(
          'help' => t('A service that performs a user_access function call for
           the current user.'),
          'file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'callback' => '_drupalgap_resource_user_access',
          'args' => array(
            array(
              'name' => 'permission',
              'optional' => FALSE,
              'source' => 'data',
              'description' => 'The permission, such as "administer nodes",' .
              ' being checked for.',
              'type' => 'string',
            ),
          ),
          'access callback' => '_drupalgap_resource_access',
          'access callback file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'access arguments' => array('access content'),
          'access arguments append' => TRUE,
        ),
        'roles_and_permissions' => array(
          'help' => t("Retrieves a user's roles and permissions."),
          'file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'callback' => '_drupalgap_resource_user_roles_and_permissions',
          'args' => array(
            array(
              'name' => 'uid',
              'optional' => FALSE,
              'source' => 'data',
              'description' => 'The user id.',
              'type' => 'int',
            ),
          ),
          'access callback' => '_drupalgap_resource_access',
          'access callback file' => array(
            'type' => 'inc',
            'module' => 'drupalgap',
            'name' => 'drupalgap.resource',
          ),
          'access arguments' => array('access content'),
          'access arguments append' => TRUE,
        ),
      ),
    ),
  );
  return $drupalgap_resource;
}
